/*
 * Open-ReedPlayer-Clover, an open source replacement for ReedPlayer-Clover
 * found in /usr/bin/ of the NES Classic
 * Copyright (C) 2018 Sam Breadman
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option),
 * at any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have recieved a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>
 *
 * The author of this program may be contacted at <reseterabreadman@gmail.com>
 *
 */

#include <stdio.h>
#include <stdbool.h>
#include <SDL2/SDL.h>
#include <SDL2/SDL_image.h>

#if !defined(ROOTFS)
#if defined(__arm__)
#define ROOTFS ""
#else
#define ROOTFS "./rootfs"
#endif
#endif

#define RESOURCE_PATH ROOTFS "/usr/share/clover-ui/resources/"

void RenderCopy(SDL_Renderer *renderer, SDL_Texture *texture, SDL_Rect srcRect, int xPos, int yPos)
{
	SDL_Rect destRect = {xPos, yPos, srcRect.w * 3, srcRect.h * 3};
	SDL_RenderCopy(renderer, texture, &srcRect, &destRect);
}

void RenderCopyEx(SDL_Renderer *renderer, SDL_Texture *texture, SDL_Rect srcRect, int xPos, int yPos, double angle, float xScale, float yScale, int xCenter, int yCenter)
{
	SDL_Rect destRect = {xPos, yPos, srcRect.w * 3 * xScale, srcRect.h * 3 * yScale};
	SDL_Point center = {xCenter, yCenter};
	SDL_RenderCopyEx(renderer, texture, &srcRect, &destRect, angle, &center, SDL_FLIP_NONE); 
}

void RenderDrawRect(SDL_Renderer *renderer, int xPos, int yPos, int w, int h)
{
	SDL_Rect destRect = {xPos, yPos, w, h};
	SDL_RenderFillRect(renderer, &destRect);
}

int main(int argc, char *argv[])
{
	SDL_Init(SDL_INIT_VIDEO);
	IMG_Init(IMG_INIT_PNG);

	SDL_Window *window = SDL_CreateWindow("Open-ReedPlayer-Clover", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, 1280, 720, SDL_WINDOW_SHOWN | SDL_WINDOW_FULLSCREEN);
	SDL_Renderer *renderer = SDL_CreateRenderer(window, -1, SDL_RENDERER_ACCELERATED | SDL_RENDERER_PRESENTVSYNC);
	SDL_ShowCursor(SDL_DISABLE);
	SDL_Event event;

	SDL_Texture *menuTextureAtlas = IMG_LoadTexture(renderer, RESOURCE_PATH "sprites/nes.png");
	
	SDL_Rect topMenubarSrcRect = {1, 43, 432, 40};
	SDL_Rect topMenubarInsetSrcRect = {145, 531, 8, 40};
	SDL_Rect titleCaptionSrcRect = {1, 205, 342, 22};
	SDL_Rect bottomMenubarSrcRect = {1, 1, 432, 40};

	enum scenes {gamelist, topMenubar, exit} scene = gamelist;

	int topMenubarYPos = -24;

	while (scene != exit)
	{
		SDL_WaitEvent(&event);
		if (event.type == SDL_QUIT)
		{
			scene = exit;
		}
		else if (event.type == SDL_KEYDOWN)
		{
			if (event.key.keysym.sym == SDLK_ESCAPE)
			{
				scene = exit;
			}
		}

		SDL_RenderClear(renderer);

		SDL_SetRenderDrawColor(renderer, 0, 21, 61, 255);
		RenderDrawRect(renderer, 0, 0, 1280, 720);
		SDL_SetRenderDrawColor(renderer, 1, 1, 1, 255);

		RenderCopy(renderer, menuTextureAtlas, topMenubarSrcRect, -8, topMenubarYPos);
		RenderCopyEx(renderer, menuTextureAtlas, topMenubarInsetSrcRect, 400, topMenubarYPos, 0, 20, 1, 0, 0); 
		RenderCopy(renderer, menuTextureAtlas, titleCaptionSrcRect, 127, 145);
		RenderCopy(renderer, menuTextureAtlas, bottomMenubarSrcRect, -8, 630);

		SDL_RenderPresent(renderer);
	}

	SDL_DestroyRenderer(renderer);
	SDL_DestroyWindow(window);

	IMG_Quit();
	SDL_Quit();

	return 0;
}
